Package 'mlitdata'

Title: What the Package Does (Title Case)
Description: More about what it does (maybe more than one line) Use four spaces when indenting paragraphs within the Description.
Authors: Who wrote it
Maintainer: The package maintainer <[email protected]>
License: What license is it under?
Version: 0.1.0
Built: 2026-07-14 04:41:46 UTC
Source: https://github.com/UchidaMizuki/mlitdata

Help Index


Attribute filter

Description

Attribute filter

Usage

mlitdata_attribute_filter(..., .env = rlang::caller_env())

Arguments

...

Attribute filter expressions.

.env

Environment to evaluate expressions in.

Value

An mlitdata_query_args object.


Get data catalog

Description

Get data catalog

Usage

mlitdata_catalog(
  catalog_id = NULL,
  catalog_fields = c("id", "title"),
  dataset_fields = NULL,
  datatype_fields = NULL,
  attribute_fields = NULL,
  path = "api/v1",
  ...
)

Arguments

catalog_id

A character vector of catalog IDs. If NULL, all catalogs are returned.

catalog_fields

A character vector or a list of fields in the catalog.

dataset_fields

A character vector or a list of fields in the dataset.

datatype_fields

A character vector or a list of fields in the datatype.

attribute_fields

A character vector or a list of fields in the attribute.

path

A character vector of the path to the API. By default, "api/v1".

...

Additional arguments used internally.

Value

A tibble of data catalog.

Examples

## Not run: 
mlitdata_catalog()
mlitdata_catalog(catalog_id = c("ipf", "nlni_ksj"))
mlitdata_catalog(catalog_id = c("ipf", "nlni_ksj"),
                 dataset_fields = c("id", "title"))
mlitdata_catalog(catalog_id = c("ipf", "nlni_ksj"),
                 dataset_fields = c("id", "title"),
                 attribute_fields = c("name", "display_name"))
mlitdata_catalog(dataset_fields = list("id",
                                       mlitdata_query("contactPoint",
                                                      "fullname")))

## End(Not run)

Location filter

Description

Location filter

Usage

mlitdata_location_filter(bbox = NULL, point = NULL, distance = NULL)

mlitdata_location_filter_rectangle(bbox = NULL)

mlitdata_location_filter_lat_lon_point(point = NULL)

mlitdata_location_filter_geodistance(point = NULL, distance = NULL)

Arguments

bbox

A bbox object from sf package.

point

A point object from sf package.

distance

A numeric value.

Value

An mlitdata_query_args object.


Build a query object

Description

Build a query object

Usage

mlitdata_query(.name, ..., .args = NULL)

Arguments

.name

The name of the query.

...

The fields of the query.

.args

The arguments of the query.

Value

An mlitdata_query object.